@@ -27,9 +27,10 @@
 
 #include <time.h>
 #include <sys/time.h>
-#include <bluetooth/bluetooth.h>
 #include <netinet/in.h>
 
+#include "lib/bluetooth.h"
+
 struct frame {
 	void		*data;
 	uint32_t	data_len;
@@ -79,10 +80,12 @@ struct frame {
 #define FILT_AVCTP	0x0800
 #define FILT_ATT 	0x1000
 #define FILT_SMP	0x2000
+#define FILT_A2MP	0x4000
 
 #define FILT_OBEX	0x00010000
 #define FILT_CAPI	0x00020000
 #define FILT_PPP	0x00040000
+#define FILT_SAP	0x00080000
 #define FILT_ERICSSON	0x10000000
 #define FILT_CSR	0x1000000a
 #define FILT_DGA	0x1000000c
@@ -107,7 +110,7 @@ struct parser_t {
 
 extern struct parser_t parser;
 
-void init_parser(unsigned long flags, unsigned long filter, 
+void init_parser(unsigned long flags, unsigned long filter,
 		unsigned short defpsm, unsigned short defcompid,
 		int pppdump_fd, int audio_fd);
 
@@ -230,9 +233,11 @@ void cmtp_dump(int level, struct frame *frm);
 void hidp_dump(int level, struct frame *frm);
 void hcrp_dump(int level, struct frame *frm);
 void avdtp_dump(int level, struct frame *frm);
-void avctp_dump(int level, struct frame *frm);
+void avctp_dump(int level, struct frame *frm, uint16_t psm);
+void avrcp_dump(int level, struct frame *frm, uint8_t hdr, uint16_t psm);
 void att_dump(int level, struct frame *frm);
 void smp_dump(int level, struct frame *frm);
+void sap_dump(int level, struct frame *frm);
 
 void obex_dump(int level, struct frame *frm);
 void capi_dump(int level, struct frame *frm);
